RQSDK
====
Ricequant SDK 是米筐量化平台中一系列的量化工具的统称，包括金融数据 API RQData、回测框架 RQAlpha-Plus、因子投研工具 RQFactor 以及股票组合优化器 RQOptimizer 四个产品。在网页平台中的“投资研究”版块所使用的所有功能即是基于 Ricequant SDK，或简称 RQSDK 的开发环境。现在米筐将这一套便捷的开发环境本地化，使您可以轻松在本地通过 RQData 调用金融数据、通过 RQAlpha Plus 进行回测、通过 RQFactor 挖掘因子、通过 RQOptimizer 进行股票组合优化，同时您还可以轻松地访问您的本地数据、用您最熟悉的本地 IDE 进行断点调试。


Features
--------
* rdk download-data  下载bundle数据
* rdk install        安装产品
* rdk license        配置rqdatac的license到环境变量
* rdk shell          打开ipython并执行 rqdatac init
* rdk update         更新rqsdk或某项产品
* rdk update-data    更新运行回测所需的历史数据
* rdk version        获取版本信息